@@ -357,6 +357,8 @@ class MARBLE_EXPORT MarbleWidget : public QWidget
      */
     qreal centerLatitude() const;
 
+    qreal heading() const;
+
     /**
      * @brief  Return how much the map will move if one of the move slots are called.
      * @return The move step.
@@ -721,6 +723,8 @@ class MARBLE_EXPORT MarbleWidget : public QWidget
      */
     void setCenterLongitude( qreal lon, FlyToMode mode = Instant );
 
+    void setHeading( qreal heading );
+
     /**
      * @brief  Move left by the moveStep.
      */
